aboutsummaryrefslogtreecommitdiffstats
path: root/include/ruby/impl/core/rregexp.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/core/rregexp.h')
-rw-r--r--include/ruby/impl/core/rregexp.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/include/ruby/impl/core/rregexp.h b/include/ruby/impl/core/rregexp.h
index e40b8d19bd..74ef52d7ae 100644
--- a/include/ruby/impl/core/rregexp.h
+++ b/include/ruby/impl/core/rregexp.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_RREGEXP_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_RREGEXP_H
+#ifndef RBIMPL_RREGEXP_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_RREGEXP_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -28,7 +28,7 @@
#include "ruby/impl/value.h"
#include "ruby/impl/value_type.h"
-#define RREGEXP(obj) RUBY3_CAST((struct RRegexp *)(obj))
+#define RREGEXP(obj) RBIMPL_CAST((struct RRegexp *)(obj))
#define RREGEXP_PTR(obj) (RREGEXP(obj)->ptr)
/** @cond INTERNAL_MACRO */
#define RREGEXP_SRC RREGEXP_SRC
@@ -46,39 +46,39 @@ struct RRegexp {
unsigned long usecnt;
};
-RUBY3_ATTR_PURE_ON_NDEBUG()
-RUBY3_ATTR_ARTIFICIAL()
+RBIMPL_ATTR_PURE_ON_NDEBUG()
+RBIMPL_ATTR_ARTIFICIAL()
static inline VALUE
RREGEXP_SRC(VALUE rexp)
{
- RUBY3_ASSERT_TYPE(rexp, RUBY_T_REGEXP);
+ RBIMPL_ASSERT_TYPE(rexp, RUBY_T_REGEXP);
VALUE ret = RREGEXP(rexp)->src;
- RUBY3_ASSERT_TYPE(ret, RUBY_T_STRING);
+ RBIMPL_ASSERT_TYPE(ret, RUBY_T_STRING);
return ret;
}
-RUBY3_ATTR_PURE_ON_NDEBUG()
-RUBY3_ATTR_ARTIFICIAL()
+RBIMPL_ATTR_PURE_ON_NDEBUG()
+RBIMPL_ATTR_ARTIFICIAL()
static inline char *
RREGEXP_SRC_PTR(VALUE rexp)
{
return RSTRING_PTR(RREGEXP_SRC(rexp));
}
-RUBY3_ATTR_PURE_ON_NDEBUG()
-RUBY3_ATTR_ARTIFICIAL()
+RBIMPL_ATTR_PURE_ON_NDEBUG()
+RBIMPL_ATTR_ARTIFICIAL()
static inline long
RREGEXP_SRC_LEN(VALUE rexp)
{
return RSTRING_LEN(RREGEXP_SRC(rexp));
}
-RUBY3_ATTR_PURE_ON_NDEBUG()
-RUBY3_ATTR_ARTIFICIAL()
+RBIMPL_ATTR_PURE_ON_NDEBUG()
+RBIMPL_ATTR_ARTIFICIAL()
static inline char *
RREGEXP_SRC_END(VALUE rexp)
{
return RSTRING_END(RREGEXP_SRC(rexp));
}
-#endif /* RUBY3_RREGEXP_H */
+#endif /* RBIMPL_RREGEXP_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file